// X2V3 hotend mount bowden adapter
// Used for copling the filament drive with the hotend mount
// GNU GPL v2
// Denis Bakin
// http://www.okob.net

include <configuration.scad>

holder_separation=0;
frame_hole_offset=0;

how_thick=9.8;
nut_size=9.24; // for 6/32 big nuts
bden_nut_size=11.6; // 8mm nuts on bowden
bden_nut_thick=5;
layer_height=0.3;
frame_hole_size=20; // Used as main frame size control, represents distance between bolt holes

f_drive_d=6.4;
f_drive_ins_gap=5.5;

//hotend_d=16;
//hotend_groove_h=1.6;
//hotend_top_h=4.7;
//hotend_in_off=10;
//hotend_in_d=17.6;

mirror([0,0,1])
adapter();

module adapter() 
{
	difference()
	{
        // Adapter main block
        union () 
        {
            translate([0,-frame_hole_offset,-0.5])
            mount_block(offset=frame_hole_size);
            translate([0,0,0])
            cylinder(r1=12,r2=10,h=how_thick,$fa=1);
        }

	    // Hotend hole and mount bolt/nuts holes
        translate([0,-frame_hole_offset,0])
        mount_frame_holes(offset=frame_hole_size);
	}
}

module mount_block(offset=25)
{
    translate([0,0,how_thick/2])
    minkowski()
    {
        cube([14,offset+18+nut_size/2,how_thick-1], center=true);
        cylinder(r=1,h=1,$fn=50);
    }
}

// Mounting frame holes (offset controls distance between)
module mount_frame_holes(offset=25)
{
	// Bolt holes
    for (i=[0:1])
    rotate(180*i)
    translate([0,offset/2-17.5,0])
	for (hole=[-1:1])
	rotate(hole*22)
	translate([0,25,-1])
	cylinder(r=(abs(hole)/2+1)*m4_diameter/2,h=how_thick+2,$fs=1);

	// Filament drive nut hole
    translate([0,0,-0.01])
    rotate(30)
	cylinder(r=bden_nut_size/2,h=bden_nut_thick+0.1,$fa=60);

    // Filament drive through hole
	cylinder(r=f_drive_d/2,h=how_thick+0.1,$fs=1);

    // Filament drive insertion hole
    translate([0,-f_drive_ins_gap/2,-0.1])
    cube([15,f_drive_ins_gap,how_thick+0.2]);

    // Insertion hole edges
    translate([13,0,-0.1])
    cylinder(r=f_drive_ins_gap/2+2,h=2*how_thick,$fs=1);
}

