// X2V3 hotend mount  
// Used for mounting makergear hotend onto X2V3 X-carriage
// GNU GPL v2
// Denis Bakin
// http://www.okob.net

include <configuration.scad>

holder_separation=0;
frame_hole_offset=0;

how_thick=9.8;
nut_size=9.24; // for 6/32 big nuts
nut_thick=3;
washer_thick=2;
washer_size=9.85;
layer_height=0.3;
frame_hole_size=20; // Used as main frame size control, represents distance between bolt holes

hotend_d=16;
hotend_groove_d=12.4;
hotend_groove_h=1.6;
hotend_top_h=4.7;
hotend_in_off=10;
hotend_in_d=17.6;

// For V2 of the mount use this difference, if don't need grooves for the 
// starps (V1) use just hotend_mount()
//difference()
//{
//	hotend_mount();
//	plastic_straps();
//}

hotend_mount();

module plastic_straps() 
{
    translate([frame_hole_size+3,-6.1,0.9])
	cube([20,4.1,2.1], center=true);
    translate([frame_hole_size+3,6.1,0.9])
	cube([20,4.1,2.1], center=true);
}

module hotend_mount() 
{
	difference()
	{
        // Hotend mount main block
        union () 
        {
            translate([0,-frame_hole_offset,-0.5])
            mount_frame(offset=frame_hole_size);
            translate([hotend_in_off,0,0])
            cylinder(r=17,h=how_thick,$fa=1);
        }

	    // Hotend hole and mount bolt/nuts holes
        translate([0,-frame_hole_offset,0])
        mount_frame_holes(offset=frame_hole_size);
	
	}

	// Bridge layer
    translate([0,-frame_hole_offset,0])
    for (i=[0:1])
    rotate(180*i)
    translate([0,frame_hole_size/2-17.5,0])
	//for (hole=[-1:1])
	//rotate(hole*22)
	translate([0,25,/*abs(hole)*washer_thick+*/(1/*-abs(hole)*/)*nut_thick])
	cylinder(r=m4_diameter/2,h=layer_height,$fs=1);
}

module mount_frame(offset=25)
{
    translate([0,0,how_thick/2])
    minkowski()
    {
        cube([14,offset+4+nut_size/2,how_thick-1], center=true);
        cylinder(r=8,h=1,$fn=50);
    }
}

// Mounting frame holes (offset controls distance between)
module mount_frame_holes(offset=25)
{
	// Bolt holes
    for (i=[0:1])
    rotate(180*i)
    translate([0,offset/2-17.5,0])
	for (hole=[-1:1])
	rotate(hole*22)
	translate([0,25,-1])
	cylinder(r=m4_diameter/2,h=how_thick+2,$fs=1);

    // Nut holes
	for (i=[0:1])
	rotate(180*i)
    translate([0,25+offset/2-17.5,-0.1])
    rotate(0)
	cylinder(r=nut_size/2,h=nut_thick+0.1,$fa=60);
	
	// Washer holes
    //for (i=[0:1])
    //rotate(180*i)
    //translate([0,offset/2-17.5,0])
	//for (hole=[-1,1])
	//rotate(hole*22)
	//translate([0,25,-0.1])
	//cylinder(r=washer_size/2,h=washer_thick+0.1,$fs=1);

	// Hotend hole
    translate([0,0,-0.01])
	cylinder(r1=hotend_d/2,r2=hotend_groove_d/2,h=how_thick-hotend_groove_h-hotend_top_h+0.01,$fs=1);
	cylinder(r=hotend_groove_d/2,h=how_thick,$fs=1);
    translate([0,0,how_thick-hotend_top_h])
	cylinder(r=hotend_d/2,h=hotend_top_h+0.1,$fs=1);
    translate([hotend_in_off,0,-0.1])
	cylinder(r=hotend_in_d/2,h=how_thick+0.2,$fs=1);
}

