// X2V3 mod of Gregs PRUSA Mendel  
// X-carriage
// Used for sliding on X axis
// GNU GPL v2
// Denis Bakin
// http://www.okob.net

include <lm8uu-holder.scad>

holder_separation=0;
frame_hole_offset=0;

fan_hole_separation=32; // check
fan_support_block=11;
fan_trap_width=3;
fan_support_thickness=11;
fan_diameter=36;
fan_hole_height=5.5;
extra_thick=2;
nut_size=9.24; // for 6/32 big nuts
nut_thick=3;
cut_from_lm8uu_holder = 3.2;

belt_clamp_thickness=2; 
belt_clamp_width=m3_diameter+3*belt_clamp_thickness+2;
belt_clamp_hole_separation=10;
belt_clamp_length=belt_clamp_hole_separation+m3_diameter+2*belt_clamp_thickness;
belt_clamp_height=m3_diameter+2*belt_clamp_thickness;

belt_width=6;
belt_thickness=1.0; 
tooth_height=0.9;
tooth_spacing=2;

with_fanmount=true;

belt_clamp_channel_height=belt_thickness+tooth_height+belt_clamp_thickness*2;

frame_hole_size=20; // Used as main frame size control, represents distance between bolt holes

for (i=[-1,1])
translate([-32+i*(belt_clamp_length/2+1),25,0])
belt_clamp();

//belt_clamp_channel();

difference() {
x_carriage();
if (with_fanmount) 
translate([40,0,0])
rotate([0,0,90])
fan_holes();
}

c_holder_off = 5.5;
lm8uu_holder_space_clean_offset = 3;

module x_carriage() 
{
	difference()
	{
		union ()
		{
			if (with_fanmount) 
			translate([40,0,0])
			rotate([0,0,90])
			fan_mount();

            // This is the flat part (base) of the whole thing
			linear_extrude(height=lm8uu_support_thickness)
			{
			polygon(points=[
				[-25+lm8uu_holder_width/2,1*((lm8uu_holder_length+belt_clamp_width)/2-c_holder_off)-0.8],
				[-25-lm8uu_holder_width/2,1*((lm8uu_holder_length+belt_clamp_width)/2-c_holder_off)-0.8],
				[-25-lm8uu_holder_width/2,-1*((lm8uu_holder_length+belt_clamp_width)/2+c_holder_off)+0.8],
				[25-lm8uu_holder_width/2,-holder_separation/2-(lm8uu_holder_length-cut_from_lm8uu_holder)],
				[20+lm8uu_holder_width/2,-holder_separation/2-(lm8uu_holder_length-cut_from_lm8uu_holder)],
				[20+lm8uu_holder_width/2,holder_separation/2+(lm8uu_holder_length-cut_from_lm8uu_holder)],
				[20+lm8uu_holder_width/2,holder_separation/2+(lm8uu_holder_length-cut_from_lm8uu_holder)],
				[25-lm8uu_holder_width/2,holder_separation/2+(lm8uu_holder_length-cut_from_lm8uu_holder)-4.5]],
				paths=[[0,1,2,3,4,5,6,7]]);
			}
            
            // Mounting frame reinforcement with cuts for lm8uu holders and belt clapmps
			difference()
			{
                union () 
                {
                    translate([0,-frame_hole_offset,0])
                    mount_frame(offset=frame_hole_size);
                    // Belt clamps
	        	    for (i=[-1,1])
			        translate([-25-13.5-1,i*(lm8uu_holder_length/2-0.8)-c_holder_off])
			        belt_clamp_socket();
                }
				translate([25-lm8uu_holder_width/2+lm8uu_support_thickness,
					-lm8uu_holder_length,-1])
				cube([lm8uu_holder_width - lm8uu_holder_space_clean_offset,2*(lm8uu_holder_length-cut_from_lm8uu_holder),8+extra_thick]);
				translate([-25-lm8uu_holder_width/2+lm8uu_holder_space_clean_offset/2, 
                           -lm8uu_holder_length/2+lm8uu_holder_space_clean_offset/2-c_holder_off,-1])
				cube([lm8uu_holder_width-lm8uu_holder_space_clean_offset,lm8uu_holder_length-lm8uu_holder_space_clean_offset,lm8uu_holder_height+2]);
			}

            // lm8uu holders
			for(i=[-1,1])
			{
				translate([50/2-lm8uu_holder_width/2,
					i*(lm8uu_holder_length+holder_separation)/2-
					lm8uu_holder_length/2-i*cut_from_lm8uu_holder,0])
				render()
                lm8uu_bearing_holder(cut=cut_from_lm8uu_holder,side=i);
			}
			translate([-50/2-lm8uu_holder_width/2,-lm8uu_holder_length/2-c_holder_off,0])
			render()
			lm8uu_bearing_holder();
		}

	    // Hotend hole and mount bolt/nuts holes
        translate([0,-frame_hole_offset,0])
        mount_frame_holes(offset=frame_hole_size);
	
	    // Holes for lm8uu zip ties
        cable_tie_holes2();
        //cable_tie_holes3();
        translate([0,-c_holder_off,-3.3])
	    cable_tie_holes1();

        // Belt clap holes re-make (also made when belt clamps are made)
		for (i=[-1,1])
		translate([-25-13.5-1,i*(lm8uu_holder_length/2-0.8)-c_holder_off])
		rotate(90*(i+1)+180) 
		belt_clamp_holes();

        // Space for x-end protruding nut holder
		translate([0,-holder_separation/2-(lm8uu_holder_length-c_holder_off/2)-5,-1])
		rotate(60)
		cylinder(r=12,h=lm8uu_support_thickness+2,$fa=60);

        // Cut anything that might still be left in the rod path
		translate([-50/2-lm8uu_holder_width/2,-lm8uu_holder_length/2,0])
		render()
        lm8uu_bearing_rod_path();
	}
}

module mount_frame(offset=25)
{
    translate([0,0,(6+extra_thick-1)/2])
    minkowski()
    {
        cube([14,offset+4+nut_size/2,6+extra_thick-1], center=true);
        cylinder(r=8,h=1,$fn=50);
    }
}

// Mounting frame holes (offset controls distance between)
module mount_frame_holes(offset=25)
{
	// Nut holes
    for (i=[0:1])
    rotate(180*i)
    translate([0,offset/2-17.5,0])
	for (hole=[-1:1])
	rotate(hole*22)
	translate([0,25,-1])
	cylinder(r=m4_diameter/2,h=lm8uu_support_thickness*2+2+extra_thick,$fs=1);

    // Bolt holes
	for (i=[0:1])
	rotate(180*i)
    translate([0,offset/2-17.5,0])
	for (hole=[-1,1])
    rotate(hole*22)
	translate([0,25,lm8uu_support_thickness+extra_thick])
    rotate(hole*7)
	cylinder(r=nut_size/2,h=nut_thick,$fa=60);
	
	// Hotend hole
    translate([0,0,(6+extra_thick-1)/2])
    minkowski()
    {
        cube([10,offset-9-nut_size/2,6+extra_thick], center=true);
        cylinder(r=8,h=1,$fn=50);
    }
}

// On the single bearing side
module cable_tie_holes1()
{
    translate([-25,0,0])
    for(a=[0,1])
    rotate([0,0,a*180])
	for (i=[-1,1])
	{
		translate([lm8uu_holder_width/2-3+a*3,((lm8uu_holder_length+6)/6)*i,5])
		rotate([0,30-a*15,0])
		cube([2,4,5],center=true);
	}
}

// On the 2 bearings side
module cable_tie_holes2()
{
    translate([25,0,0])
    for(a=[0,1])
    rotate([0,0,a*180])
    for (i=[-1,1])
	translate([-lm8uu_holder_width/2+3,(holder_separation/2+lm8uu_holder_length*0.7-cut_from_lm8uu_holder)*i,2])
	rotate([0,-30+a*30,0])
	cube([2,4,5],center=true);
}
module cable_tie_holes3()
{
    translate([25,0,0])
    for(a=[0,1])
    rotate([0,0,a*180])
    for (i=[-1,1])
	translate([-lm8uu_holder_width/2+3,(holder_separation/2+lm8uu_holder_length*0.3-cut_from_lm8uu_holder)*i,2])
	rotate([0,-30+a*30,0])
	cube([2,4,5],center=true);
}

module belt_clamp_socket()
{
	difference()
	{
		translate([0,0,belt_clamp_height/2])
		union()
		{
			cube([belt_clamp_hole_separation,belt_clamp_width,belt_clamp_height],
				center=true);

			translate([belt_clamp_hole_separation/2,0,lm8uu_holder_height/2-belt_clamp_height/2])
            scale([0.7,1,1])
			cylinder(r=belt_clamp_width/2,h=lm8uu_holder_height,center=true);

			translate([-belt_clamp_hole_separation/2,0,0])
            scale([0.7,1,1])
			cylinder(r=belt_clamp_width/2,h=belt_clamp_height,center=true);
		}
		belt_clamp_holes();
	}
}

module belt_clamp_channel()
{
	difference()
	{
		translate([0,0,belt_clamp_channel_height/2])
		union()
		{
			cube([belt_clamp_hole_separation,
				belt_clamp_width,belt_clamp_channel_height],center=true);
			for(i=[-1,1])
			translate([i*belt_clamp_hole_separation/2,0,0])
            scale([0.7,1,1])
			cylinder(r=belt_clamp_width/2,h=belt_clamp_channel_height,center=true);
		}

		for(i=[-1,1])
		translate([i*belt_clamp_hole_separation/2,0,-1])
		rotate(360/16)
		cylinder(r=m3_diameter/2,h=belt_clamp_channel_height+2,$fn=8);

		translate([-belt_width/2,-belt_clamp_width/2-1,
			belt_clamp_channel_height-belt_thickness-tooth_height])
		cube([belt_width,belt_clamp_width+2,belt_thickness+tooth_height+1]);
	}
}

module belt_clamp_holes()
{
	translate([0,0,lm8uu_holder_height/2])
	{
		for(i=[-1,1])
		translate([i*belt_clamp_hole_separation/2,0,0])
		cylinder(r=m3_diameter/2,h=lm8uu_holder_height+2,center=true,$fn=8);
	
		/*rotate([90,0,0])
		rotate(360/16)
		cylinder(r=m3_diameter/2-0.3 ,h=belt_clamp_width+2,center=true,$fn=8);

		rotate([90,0,0]) 
		translate([0,0,belt_clamp_width/2])
		cylinder(r=m3_nut_diameter/2, h=3.4,center=true,$fn=6);

		rotate([-90,0,0]) 
		translate([0,0,belt_clamp_width/2])
		cylinder(r=m3_nut_diameter/2+0.3, h=3.4,center=true,$fn=8);*/
	}
}

belt_clamp_clamp_height=tooth_height+belt_clamp_thickness*2;


module belt_clamp()
{
	difference()
	{
		translate([0,0,belt_clamp_clamp_height/2])
		union()
		{
			cube([belt_clamp_hole_separation,belt_clamp_width,
				belt_clamp_clamp_height],center=true);
			for(i=[-1,1])
			translate([i*belt_clamp_hole_separation/2,0,0])
            scale([0.7,1,1])
			cylinder(r=belt_clamp_width/2,h=belt_clamp_clamp_height,center=true);
		}

		for(i=[-1,1])
		translate([i*belt_clamp_hole_separation/2,0,-1])
		rotate(360/16)
		cylinder(r=m3_diameter/2,h=belt_clamp_clamp_height+2,$fn=8);

		for(i=[-3:3])
		translate([-belt_width/2,-tooth_spacing/4+i*tooth_spacing,
			belt_clamp_clamp_height-tooth_height])
		cube([belt_width,tooth_spacing/2,tooth_height+1]);
	}
}

fan_hole_separation=32; // check
fan_support_block=11;
fan_trap_width=3;
fan_support_thickness=11;
fan_diameter=36;
fan_hole_height=5.5;

module fan_mount() 
{
	difference()
	{
		union ()
		{
			translate([0,0,fan_support_block/4])
			cube([fan_hole_separation+fan_support_block,fan_support_thickness,
				fan_support_block/2],center=true);
			
			for (i=[-1,1])
			translate([i*fan_hole_separation/2,0,fan_support_block/2])
			rotate([90,0,0])
			cylinder(r=fan_support_block/2,h=fan_support_block,center=true,$fn=20);
			
			translate([0,0,fan_support_block/2])
			cube([fan_hole_separation,fan_support_thickness,fan_support_block],
				center=true);
			translate([0,6,lm8uu_support_thickness/2])
			cube([fan_hole_separation+fan_support_block,fan_support_thickness+12,
				lm8uu_support_thickness],center=true);
		}
		translate([0,0,fan_hole_separation/2+fan_hole_height])
		rotate([-90,0,0])
		cylinder(r=fan_diameter/2,h=fan_support_thickness+2,center=true);
	}
}

module fan_holes() {
		for(i=[-1,1])
		{
			translate([i*fan_hole_separation/2,0,fan_hole_height])
			{
				rotate([90,0,0])
				rotate(180/8)
				cylinder(r=m3_diameter/2,h=fan_support_thickness+0.1,
					center=true,$fn=8);
				translate([0,0,0])
				rotate([90,0,0])
				rotate([0,0,180/6])
				cylinder(r=(m3_nut_diameter-0.5)/2,h=fan_trap_width,
					center=true,$fn=6);
				color([1,0,0])
				translate([0,0,-(fan_hole_height+1)/2])
				cube([(m3_nut_diameter-0.5)*cos(30),fan_trap_width,
					fan_hole_height+1],center=true);
			}
		}
}

function triangulate (point1, point2, length1, length2) = 
point1 + 
length1*rotated(
atan2(point2[1]-point1[1],point2[0]-point1[0])+
angle(distance(point1,point2),length1,length2));

function distance(point1,point2)=
sqrt((point1[0]-point2[0])*(point1[0]-point2[0])+
(point1[1]-point2[1])*(point1[1]-point2[1]));

function angle(a,b,c) = acos((a*a+b*b-c*c)/(2*a*b)); 

function rotated(a)=[cos(a),sin(a),0];
